==> id-broker-plugin_2.2.4.tar.gz: id-broker-plugin-2.2.4/tests/host/98_ucsschool-id-broker-performance/01_prov_school_classes_get.py <==
#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -l -v
## -*- coding: utf-8 -*-
## desc: check performance of GET /ucsschool/apis/provisioning/v1/{school_authority}/classes/{id}
## tags: [ucsschool-id-broker, provisioning-api, performance]
## exposure: safe
## packages: []
## bugs: [54547]

import os.path

import pytest

BASE_DIR = "/var/lib/id-broker-performance-tests"
RESULT_DIR = os.path.join(BASE_DIR, "results")
LOCUST_FILES_DIR = os.path.join(BASE_DIR, "performance_tests", "provisioning")

LOCUST_FILE = "school_classes_get.py"
LOCUST_FILE_PATH = os.path.join(LOCUST_FILES_DIR, LOCUST_FILE)
RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, "provisioning_school_classes_get")
HOST = "provisioning"
URL_NAME = "/ucsschool/apis/provisioning/v1/{school_authority}/classes/{id}"


@pytest.fixture(scope="module")
def run_test(execute_test, host_from_env, verify_test_sent_requests):
    execute_test(LOCUST_FILE_PATH, RESULT_FILE_BASE_PATH, host_from_env(HOST))
    # fail in fixture, so pytest prints the output of Locust, regardless which test_*() function started Locust
    verify_test_sent_requests(RESULT_FILE_BASE_PATH)


def test_failure_count(check_failure_count, run_test):
    check_failure_count(RESULT_FILE_BASE_PATH)


def test_rps(check_rps, run_test):
    check_rps(RESULT_FILE_BASE_PATH, URL_NAME, 0.1)  # TODO: set desired target performance


def test_95_percentile(check_95_percentile, run_test):
    check_95_percentile(RESULT_FILE_BASE_PATH, URL_NAME, 10000)  # TODO: set desired target performance

==> id-broker-plugin_2.3.2.tar.gz: id-broker-plugin-2.3.2/tests/host/98_ucsschool-id-broker-performance/01_prov_school_classes_get.py <==
#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -l -v
## -*- coding: utf-8 -*-
## desc: check performance of GET /ucsschool/apis/provisioning/v1/{school_authority}/classes/{id}
## tags: [ucsschool-id-broker, provisioning-api, performance]
## exposure: safe
## packages: []
## bugs: [54547]

import os.path

import pytest

BASE_DIR = "/var/lib/id-broker-performance-tests"
RESULT_DIR = os.path.join(BASE_DIR, "results")
LOCUST_FILES_DIR = os.path.join(BASE_DIR, "performance_tests", "provisioning")

LOCUST_FILE = "school_classes_get.py"
LOCUST_FILE_PATH = os.path.join(LOCUST_FILES_DIR, LOCUST_FILE)
RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, "provisioning_school_classes_get")
HOST = "provisioning"
URL_NAME = "/ucsschool/apis/provisioning/v1/{school_authority}/classes/{id}"


@pytest.fixture(scope="module")
def run_test(execute_test, host_from_env, verify_test_sent_requests):
    execute_test(LOCUST_FILE_PATH, RESULT_FILE_BASE_PATH, host_from_env(HOST))
    # fail in fixture, so pytest prints the output of Locust, regardless which test_*() function started Locust
    verify_test_sent_requests(RESULT_FILE_BASE_PATH)


def test_failure_count(check_failure_count, run_test):
    check_failure_count(RESULT_FILE_BASE_PATH)


def test_rps(check_rps, run_test):
    check_rps(
        RESULT_FILE_BASE_PATH, URL_NAME, 0.1
    )  # TODO: set desired target performance


def test_95_percentile(check_95_percentile, run_test):
    check_95_percentile(
        RESULT_FILE_BASE_PATH, URL_NAME, 10000
    )  # TODO: set desired target performance
